<?php

/**
 * @file
 * Helper functions for UMP module.
 */

/**
 * Helper function to get the UMP rules defined for the current user.
 */
function ump_get_ump_crud_rules() {
  global $user;
  $return_rules = array();
  $rules = ump_get_ump_crud_rules_all();
  if (is_array($rules)) {
    foreach ($rules as $rule_key) {
      $rule = variable_get($rule_key);
      if (isset($user->roles[$rule["select_role"]])) {
        array_push($return_rules, $rule);
      }
    }
  }
  return $return_rules;
}

/**
 * Helper function to return array of defined UMP permissions.
 */
function ump_get_ump_permissions() {
  $permission_array = array();
  $rules = ump_get_ump_crud_rules_all();
  foreach ($rules as $rule_key) {
    $rule = variable_get($rule_key);

    if ($rule["allow_to_create_enable"] == 1) {
      $permission_array[$rule["select_role"]]["create"][$rule["allow_to_create_role"]] = 1;
      if ($rule["allow_to_create_overtake"] == 1) {
        $permission_array[$rule["select_role"]]["create"][$rule["allow_to_create_role"]] = array("overtake" => $rule["allow_to_create_overtake_field"]);
      }
    }
    if ($rule["allow_to_view_enable"] == 1) {
      $permission_array[$rule["select_role"]]["view"][$rule["allow_to_view_role"]]["which"] = $rule["allow_to_view_which"];
      if ($rule["allow_to_view_which"] == "if_share_common_field") {
        $permission_array[$rule["select_role"]]["view"][$rule["allow_to_view_role"]]["common_field"] = $rule["allow_to_view_common_field"];
      }
    }
    if ($rule["allow_to_edit_enable"] == 1) {
      $permission_array[$rule["select_role"]]["edit"][$rule["allow_to_edit_role"]]["which"] = $rule["allow_to_edit_which"];
      if ($rule["allow_to_edit_which"] == "if_share_common_field") {
        $permission_array[$rule["select_role"]]["edit"][$rule["allow_to_edit_role"]]["common_field"] = $rule["allow_to_edit_common_field"];
      }
    }
    if ($rule["allow_to_delete_enable"] == 1) {
      $permission_array[$rule["select_role"]]["delete"][$rule["allow_to_delete_role"]]["which"] = $rule["allow_to_delete_which"];
      if ($rule["allow_to_delete_which"] == "if_share_common_field") {
        $permission_array[$rule["select_role"]]["delete"][$rule["allow_to_delete_role"]]["common_field"] = $rule["allow_to_delete_common_field"];
      }
    }
  }

  return $permission_array;
}

/**
 * Helper function to return creator UID.
 */
function ump_get_ump_user_created_by_uid($uid) {
  $load_user = user_load($uid);
  if ($load_user && isset($load_user->field_ump_created_by[LANGUAGE_NONE][0]['value'])) {
    return $load_user->field_ump_created_by[LANGUAGE_NONE][0]['value'];
  }
  return NULL;
}

/**
 * Helper function to get the all UMP rules defined.
 */
function ump_get_ump_crud_rules_all() {
  global $conf;
  $rules = [];
  foreach ($conf as $key => $value) {
    if (substr($key, 0, 14) === "ump_CRUD_rule_") {
      $rules[] = $key;
    }
  }
  return $rules;
}

/**
 * Helper function to get the all user roles defined.
 */
function ump_get_user_roles() {
  return user_roles(TRUE);
}

/**
 * Helper function to get all user fields defined.
 */
function ump_get_user_user_fields() {
  $field_info_instances = field_info_instances('user', 'user');
  $user_fields = [];
  // Define the fields which we don't want to show.
  $fields_to_skip = ['field_ump_created_by'];
  foreach ($field_info_instances as $field_info_instance_key => $field_info_instance_value) {
    if (!in_array($field_info_instance_key, $fields_to_skip)) {
      $user_fields[$field_info_instance_key] = $field_info_instance_value["label"];
    }
  }
  return $user_fields;
}
